@@ -1,13 +1,13 @@
-from frost.client.client import FrostClient
-from frost.client.socketio import threaded
-from frost.client.headers import Header, Method, Status
 from frost.client.auth import get_auth
+from frost.client.client import FrostClient
+from frost.client.headers import Status
+from frost.client.objects import Memory
+from frost.client.socketio import threaded
 
 __all__ = (
     'FrostClient',
-    'Header',
-    'Method',
     'Status',
     'threaded',
-    'get_auth'
+    'get_auth',
+    'Memory'
 )
