@@ -1,11 +1,14 @@
-from typing import Any, Dict, Union
-from pathlib import Path
 import json
+from pathlib import Path
 
-from frost.client.headers import Header
-from frost.client.methods import exec_method
-from frost.client.socketio import BaseClient
 from frost.client.auth import get_auth
+from frost.client.events import (
+    Auth,
+    Msgs,
+    Rooms
+)
+from frost.client.socketio import BaseClient, threaded
+from frost.ext import Handler
 
 
 class FrostClient(BaseClient):
@@ -22,8 +25,12 @@ class FrostClient(BaseClient):
         """
         super(FrostClient, self).__init__(ip, port)
 
-        frost_file = Path('.frost')
+        # Load up cogs
+        Auth()
+        Msgs()
+        Rooms()
 
+        frost_file = Path('.frost')
         if not frost_file.exists():
             with open(str(frost_file), 'w') as f:
                 json.dump({}, f)
@@ -42,28 +49,28 @@ class FrostClient(BaseClient):
         """
         self.close()
 
-    def recieve(self) -> Any:
-        """Receive data from the server and execute the specified method in the response headers.
-
-        :return: Data received from the server
-        :rtype: Any
+    def connect(self) -> None:
+        """Connect to the server and begin listening for events.
         """
-        data = super(FrostClient, self).recieve()
-        headers = data['headers']
-        method = headers[Header.METHOD.value]
+        super().connect()
+        self._listen()
 
-        resp = exec_method(method, data)
-        return resp
+    @threaded(daemon=True)
+    def _listen(self) -> None:
+        """Listen for events and handle them.
+        """
+        handler = Handler()
 
-    def login(self, username: str, password: str) -> Any:
+        while True:
+            handler.handle(self.recieve())
+
+    def login(self, username: str, password: str) -> None:
         """Login to the server.
 
         :param username: The username of the account
         :type username: str
         :param password: The password of the account
         :type password: str
-        :return: Data received from the server
-        :rtype: Any
         """
         self.send({
             'headers': {
@@ -72,7 +79,6 @@ class FrostClient(BaseClient):
             'username': username,
             'password': password
         })
-        return self.recieve()
 
     def register(self, username: str, password: str) -> None:
         """Register an account on the server.
@@ -89,12 +95,13 @@ class FrostClient(BaseClient):
             'username': username,
             'password': password
         })
-        return self.recieve()
 
     @get_auth
-    def send_msg(self, msg: str, token: str, id_: str) -> None:
-        """Send a message to other users on the server.
+    def send_msg(self, room_id: int, msg: str, token: str, id_: str) -> None:
+        """Send a message to other users on a server in a specific room.
 
+        :param room_id: The ID of the room to send the message to
+        :type room_id: int
         :param msg: The desired message to send
         :type msg: str
         :param token: The user's token, auto filled by :meth:`frost.client.auth.get_auth`
@@ -104,62 +111,181 @@ class FrostClient(BaseClient):
         """
         self.send({
             'headers': {
-                Header.AUTH_TOKEN.value: token,
-                Header.ID_TOKEN.value: id_,
+                'token': token,
+                'id': id_,
                 'path': 'messages/send_msg'
             },
-            'msg': msg
+            'msg': msg,
+            'room_id': room_id
         })
 
     @get_auth
-    def get_all_msgs(
+    def get_room_msgs(
+        self,
+        room_id: int,
+        token: str,
+        id_: str
+    ) -> None:
+        """Get all messages from a specific room in a server.
+
+        :param room_id: The ID of the room to get the messages from
+        :type room_id: int
+        :param token: The user's token, auto filled by :meth:`frost.client.auth.get_auth`
+        :type token: str
+        :param id_: The user's ID, auto filled by :meth:`frost.client.auth.get_auth`
+        :type id_: str
+        """
+        self.send({
+            'headers': {
+                'path': 'messages/get_room_msgs',
+                'token': token,
+                'id': id_
+            },
+            'room_id': room_id
+        })
+
+    @get_auth
+    def create_room(
+        self,
+        room_name: str,
+        token: str,
+        id_: str
+    ) -> None:
+        """Create a new room in a server.
+
+        :param room_name: The name of the room to create
+        :type room_name: str
+        :param token: The user's token, auto filled by :meth:`frost.client.auth.get_auth`
+        :type token: str
+        :param id_: The user's ID, auto filled by :meth:`frost.client.auth.get_auth`
+        :type id_: str
+        """
+        self.send({
+            'headers': {
+                'path': 'rooms/create',
+                'token': token,
+                'id': id_
+            },
+            'room_name': room_name
+        })
+
+    @get_auth
+    def join_room(
+        self,
+        invite_code: str,
+        token: str,
+        id_: str
+    ) -> None:
+        """Join a room in a server with an invite code.
+
+        :param invite_code: The invite code the room to join
+        :type invite_code: str
+        :param token: The user's token, auto filled by :meth:`frost.client.auth.get_auth`
+        :type token: str
+        :param id_: The user's ID, auto filled by :meth:`frost.client.auth.get_auth`
+        :type id_: str
+        """
+        self.send({
+            'headers': {
+                'path': 'rooms/join',
+                'token': token,
+                'id': id_
+            },
+            'invite_code': invite_code
+        })
+
+    @get_auth
+    def leave_room(
+        self,
+        room_id: int,
+        token: str,
+        id_: str
+    ) -> None:
+        """Leave a joined room in a server.
+
+        :param room_id: The ID of the room to leave
+        :type room_id: int
+        :param token: The user's token, auto filled by :meth:`frost.client.auth.get_auth`
+        :type token: str
+        :param id_: The user's ID, auto filled by :meth:`frost.client.auth.get_auth`
+        :type id_: str
+        """
+        self.send({
+            'headers': {
+                'path': 'rooms/leave',
+                'token': token,
+                'id': id_
+            },
+            'room_id': room_id
+        })
+
+    @get_auth
+    def get_invite_code(
+        self,
+        room_id: int,
+        token: str,
+        id_: str
+    ) -> None:
+        """Get the invite code of a room in a server.
+
+        :param room_id: The ID of the room to get an invite code from
+        :type room_id: int
+        :param token: The user's token, auto filled by :meth:`frost.client.auth.get_auth`
+        :type token: str
+        :param id_: The user's ID, auto filled by :meth:`frost.client.auth.get_auth`
+        :type id_: str
+        """
+        self.send({
+            'headers': {
+                'path': 'rooms/get_invite_code',
+                'token': token,
+                'id': id_
+            },
+            'room_id': room_id
+        })
+
+    @get_auth
+    def get_joined_rooms(
         self,
         token: str,
         id_: str
-    ) -> Dict[str, Dict[str, Union[str, Dict[str, str]]]]:
-        """Get all messages from the server.
+    ) -> None:
+        """Get all the joined rooms of the currently logged in user.
 
         :param token: The user's token, auto filled by :meth:`frost.client.auth.get_auth`
         :type token: str
         :param id_: The user's ID, auto filled by :meth:`frost.client.auth.get_auth`
         :type id_: str
-        :return: All messages
-        :rtype: Dict[str, Dict[str, Union[str, Dict[str, str]]]]
         """
         self.send({
             'headers': {
-                Header.AUTH_TOKEN.value: token,
-                Header.ID_TOKEN.value: id_,
-                'path': 'messages/get_all_msgs'
+                'path': 'rooms/get_all_joined',
+                'token': token,
+                'id': id_
             }
         })
-        return self.recieve()
 
     @get_auth
-    def get_new_msgs(
+    def get_room_members(
         self,
+        room_id: int,
         token: str,
         id_: str
-    ) -> Dict[str, Dict[str, Union[str, Dict[str, str]]]]:
-        """Get new, unread messages from the server.
+    ) -> None:
+        """Get all the members of a specific room.
 
+        :param room_id: The ID of the room to get the members of
+        :type room_id: int
         :param token: The user's token, auto filled by :meth:`frost.client.auth.get_auth`
         :type token: str
         :param id_: The user's ID, auto filled by :meth:`frost.client.auth.get_auth`
         :type id_: str
-        :return: New, unread messages
-        :rtype: Dict[str, Dict[str, Union[str, Dict[str, str]]]]
         """
-        with open('.frost', 'r') as f:
-            last = json.load(f).get('last_msg_timestamp')
-
         self.send({
             'headers': {
-                Header.AUTH_TOKEN.value: token,
-                Header.ID_TOKEN.value: id_,
-                'path': 'messages/get_new_msgs'
+                'path': 'rooms/get_members',
+                'token': token,
+                'id': id_
             },
-            'last_msg_timestamp': last
+            'room_id': room_id
         })
-
-        return self.recieve()
