@@ -1,15 +1,15 @@
+from frost.server.auth import auth_required
+from frost.server.headers import Status
+from frost.server.logger import logger
+from frost.server.objects import Memory
 from frost.server.server import FrostServer
 from frost.server.socketio import threaded
-from frost.server.headers import Header, Method, Status
-from frost.server.auth import auth_required
-from frost.server.logger import logger
 
 __all__ = (
     'FrostServer',
-    'Header',
-    'Method',
     'Status',
     'threaded',
     'auth_required',
-    'logger'
+    'logger',
+    'Memory'
 )
