@@ -1,15 +1,11 @@
-from typing import Any, Callable, Tuple
-from functools import wraps
-from pathlib import Path
-import struct
 import socket
-import json
+from pathlib import Path
+from typing import Any, Callable, Tuple
 
 from frost.ext import Handler
-from frost.server.room import Room
-from frost.server.methods import Auth, Msgs
+from frost.server.cogs import Auth, Msgs, Rooms
+from frost.server.objects import Memory, UserObj
 from frost.server.socketio import BaseServer, threaded
-from frost.server.storage.defaults import DEFAULT_FORMAT
 
 
 def send_partial(send_func: Callable, conn: 'socket.socket') -> Callable:
@@ -43,59 +39,55 @@ class FrostServer(BaseServer):
         # Load up the cogs
         Auth()
         Msgs()
+        Rooms()
 
         path = Path(file)
 
         self._name = path.name
         self._dir = path.parent
 
-        self._rooms = list()
-
         self.func = self.on_user_connect
 
-        storage = Path('storage.json')
-        if not storage.exists():
-            with open(str(storage), 'w') as f:
-                json.dump(DEFAULT_FORMAT, f, indent=2)
-
-    def room(self, *deco_args: Any, **deco_kwargs: Any) -> Callable:
-        """Create a room.
-
-        :raises NotImplementedError: This decorator is not implemented yet
-        """
-        raise NotImplementedError
-
-        def inner(func) -> Callable:
-            @wraps(func)
-            def execute(*args: Any, **kwargs: Any) -> Any:
-                room = Room(*deco_args, **deco_kwargs)
-                self._rooms.append(room)
-                return func(room)
-
-            return execute
-
-        return inner
+        db = Path('pyfrost.sqlite3')
+        if not db.exists():
+            from frost.server.database import init_db
+            init_db()
 
     @threaded()
     def on_user_connect(self, conn: 'socket.socket', addr: Tuple[str, int]) -> None:
         """Handles the connection of a client and executes tasks accordingly.
 
         :param conn: The client's connection
-        :type conn: socket.socket
+        :type conn: 'socket.socket'
         :param addr: The user's IP address and port
         :type addr: Tuple[str, int]
         """
-        handler = Handler(send_partial(self.send, conn))
+        user = UserObj(addr, conn)
+        Memory.all_users[addr] = user
+
+        handler = Handler()
 
         while True:
             try:
                 data = self.recieve(conn)
 
-            except struct.error:
+            except Exception:
+                Memory.all_users.pop(addr)
+
+                for id_, auth_user in Memory.logged_in_users.items():
+                    if auth_user.addr == addr:
+                        Memory.logged_in_users.pop(id_)
+                        break
+
                 break
 
             else:
-                handler.handle(data)
+                handler.handle(
+                    data,
+                    addr=addr,
+                    send=self.send,
+                    client_send=send_partial(self.send, conn)
+                )
 
     def run(self, ip: str = '127.0.0.1', port: int = 5555) -> None:
         """Runs the FrostServer.
