@@ -1,6 +1,5 @@
 from frost.server.storage.base import Base
-from frost.server.storage.models import User, Room, Message
 from frost.server.storage.exceptions import DuplicateValueError
-
+from frost.server.storage.models import Message, Room, User
 
 __all__ = ('Base', 'User', 'Room', 'Message', 'DuplicateValueError')
