@@ -25,8 +25,4 @@ def main():
 
 
 if __name__ == "__main__":
-    try:
-        main()
-
-    finally:
-        sys.stderr.close()
+    main()
